@@ -76,7 +76,7 @@ def validate_ipv4(anm):
     #TODO: only include bound interfaces
 
     # check globally unique ip addresses
-    all_ints = [i for n in g_ipv4.nodes("is_l3device")
+    all_ints = [i for n in g_ipv4.l3devices()
             for i in n.physical_interfaces
             if i.is_bound] # don't include unbound interfaces
     all_int_ips = [i.ip_address for i in all_ints]
