@@ -35,6 +35,7 @@ class RouterCompiler(DeviceCompiler):
             use_ipv4 = False
             use_ipv6 = True
 
+        #TODO: return config_stanza rather than a dict
         data = {  # TODO: this is platform dependent???
             'neighbor': neigh.label,
             'use_ipv4': use_ipv4,
@@ -61,6 +62,7 @@ class RouterCompiler(DeviceCompiler):
             use_ipv4 = False
             use_ipv6 = True
 
+        #TODO: return config_stanza rather than a dict
         data = {  # TODO: change templates to access from node.bgp.lo_int
             'neighbor': neigh.label,
             'use_ipv4': use_ipv4,
@@ -84,6 +86,7 @@ class RouterCompiler(DeviceCompiler):
         phy_node = self.anm['phy'].node(node)
         ipv4_node = self.anm['ipv4'].node(node)
 
+        node.add_stanza("ip")
         node.ip.use_ipv4 = phy_node.use_ipv4 or False
         node.ip.use_ipv6 = phy_node.use_ipv6 or False
         if not (node.ip.use_ipv4 and node.ip.use_ipv6):
@@ -108,14 +111,18 @@ class RouterCompiler(DeviceCompiler):
             self.isis(node)
         if self.anm.has_overlay('eigrp') and node in self.anm['eigrp']:
             self.eigrp(node)
-        #TODO: allow this to work for ibgp and ebgp
-        if (
-            (self.anm.has_overlay('ebgp_v4') and node in self.anm['ebgp_v4'])
-            or (self.anm.has_overlay('ibgp_v4') and node in self.anm['ibgp_v4'])
-            or (self.anm.has_overlay('ebgp_v6') and node in self.anm['ebgp_v6'])
-            or (self.anm.has_overlay('ibgp_v6') and node in self.anm['ibgp_v6'])
-            or
-            (self.anm.has_overlay('bgp') and node in self.anm['bgp'])):
+        #TODO: drop bgp overlay
+        bgp_overlays = ["bgp", "ebgp_v4", "ibgp_v4", "ebgp_v6", "ibgp_v6"]
+        use_bgp = False
+        for overlay in bgp_overlays:
+            if (self.anm.has_overlay(overlay)
+                and node in self.anm[overlay]
+                and self.anm[overlay].node(node).degree() > 0
+                ):
+                use_bgp = True
+                break
+
+        if use_bgp:
             self.bgp(node)
 
     def interfaces(self, node):
@@ -226,13 +233,14 @@ class RouterCompiler(DeviceCompiler):
 
         g_ospf = self.anm['ospf']
         g_ipv4 = self.anm['ipv4']
+        ospf_node = g_ospf.node(node)
         ospf_stanza = node.add_stanza("ospf")
 
         node.ospf.ipv4_mpls_te = False  # default, inherited enable if necessary
 
         node.ospf.loopback_area = g_ospf.node(node).area or 0
 
-        node.ospf.process_id = 1  # TODO: set this in build_network module
+        node.ospf.process_id = ospf_node.process_id
         node.ospf.lo_interface = self.lo_interface
 
         node.ospf.ospf_links = []
@@ -309,6 +317,8 @@ class RouterCompiler(DeviceCompiler):
             g_ipv6 = self.anm['ipv6']
         asn = phy_node.asn
         node.asn = asn
+        node.add_stanza("bgp")
+
         node.bgp.ipv4_advertise_subnets = []
         if node.ip.use_ipv4:
             node.bgp.ipv4_advertise_subnets = \
@@ -330,14 +340,15 @@ class RouterCompiler(DeviceCompiler):
                 continue  # exclude from regular ibgp config (eg VRF, VPLS, etc)
 
             data = self.ibgp_session_data(session, ip_version=4)
+            bgp_stanza = config_stanza(**data)
 
             direction = session.direction
             if direction == 'down':
-                ibgp_rr_clients.append(data)
+                ibgp_rr_clients.append(bgp_stanza)
             elif direction == 'up':
-                ibgp_rr_parents.append(data)
+                ibgp_rr_parents.append(bgp_stanza)
             else:
-                ibgp_neighbors.append(data)
+                ibgp_neighbors.append(bgp_stanza)
 
         # TODO: check v6 hierarchy only created if node set to being v4 or v6
 
@@ -348,14 +359,15 @@ class RouterCompiler(DeviceCompiler):
                     log.debug('Skipping excluded ibgp session %s' % session)
                     continue  # exclude from regular ibgp config (eg VRF, VPLS, etc)
                 data = self.ibgp_session_data(session, ip_version=6)
+                bgp_stanza = config_stanza(**data)
 
                 direction = session.direction
                 if direction == 'down':
-                    ibgp_rr_clients.append(data)
+                    ibgp_rr_clients.append(bgp_stanza)
                 elif direction == 'up':
-                    ibgp_rr_parents.append(data)
+                    ibgp_rr_parents.append(bgp_stanza)
                 else:
-                    ibgp_neighbors.append(data)
+                    ibgp_neighbors.append(bgp_stanza)
 
         # TODO: update this to use ibgp_v4 and ibgp_v6 overlays
 
@@ -372,7 +384,8 @@ class RouterCompiler(DeviceCompiler):
                 log.debug('Skipping excluded ebgp session %s' % session)
                 continue  # exclude from regular ibgp config (eg VRF, VPLS, etc)
             data = self.ebgp_session_data(session, ip_version=4)
-            ebgp_neighbors.append(data)
+            bgp_stanza = config_stanza(**data)
+            ebgp_neighbors.append(bgp_stanza)
 
         if node.ip.use_ipv6:
             g_ebgp_v6 = self.anm['ebgp_v6']
@@ -382,10 +395,11 @@ class RouterCompiler(DeviceCompiler):
                     log.debug('Skipping excluded ebgp session %s' % session)
                     continue  # exclude from regular ibgp config (eg VRF, VPLS, etc)
                 data = self.ebgp_session_data(session, ip_version=6)
-                ebgp_neighbors.append(data)
+                bgp_stanza = config_stanza(**data)
+                ebgp_neighbors.append(bgp_stanza)
 
+        ebgp_neighbors = sorted(ebgp_neighbors, key = lambda x: x.asn)
         node.bgp.ebgp_neighbors = ebgp_neighbors
-        node.bgp.ebgp_neighbors.sort('asn')
 
         return
 
@@ -393,7 +407,7 @@ class RouterCompiler(DeviceCompiler):
         g_eigrp = self.anm['eigrp']
         g_ipv4 = self.anm['ipv4']
         eigrp_node = self.anm['eigrp'].node(node)
-        node.eigrp.name = eigrp_node.name
+        node.eigrp.process_id = eigrp_node.process_id
 
         ipv4_networks = set()
         for interface in node.physical_interfaces:
@@ -415,6 +429,8 @@ class RouterCompiler(DeviceCompiler):
 
     def isis(self, node):
         g_isis = self.anm['isis']
+        isis_node = g_isis.node(node)
+        process_id = isis_node.process_id
 
         node.isis.ipv4_mpls_te = False  # default, inherited enable if necessary
 
@@ -429,7 +445,7 @@ class RouterCompiler(DeviceCompiler):
                 isis_node = g_isis.node(node)
                 interface.isis = {
                     'metric': isis_int.metric,
-                    'process_id': node.isis.process_id,
+                    'process_id': process_id,
                     'use_ipv4': node.ip.use_ipv4,
                     'use_ipv6': node.ip.use_ipv6,
                     'multipoint': isis_int.multipoint,
@@ -443,7 +459,7 @@ class RouterCompiler(DeviceCompiler):
 
         # TODO: generalise loopbacks to allow more than one per device
 
-        node.isis.process_id = isis_node.process_id
+        node.isis.process_id = process_id
         node.isis.lo_interface = self.lo_interface
 
 # set isis on loopback_zero
