@@ -9,6 +9,7 @@ import string
 import itertools
 from autonetkit.ank_utils import alphabetical_sort as alpha_sort
 from autonetkit.compilers.device.quagga import QuaggaCompiler
+from autonetkit.nidb import config_stanza
 
 class NetkitCompiler(PlatformCompiler):
     """Netkit Platform Compiler"""
@@ -22,9 +23,10 @@ class NetkitCompiler(PlatformCompiler):
         g_phy = self.anm['phy']
         quagga_compiler = QuaggaCompiler(self.nidb, self.anm)
 # TODO: this should be all l3 devices not just routers
-        for phy_node in g_phy.nodes('is_l3device', host=self.host, syntax='quagga'):
+        for phy_node in g_phy.l3devices(host=self.host, syntax='quagga'):
             folder_name = naming.network_hostname(phy_node)
             nidb_node = self.nidb.node(phy_node)
+            nidb_node.add_stanza("render")
             #TODO: order by folder and file template src/dst
             nidb_node.render.base = os.path.join("templates","quagga")
             nidb_node.render.template = os.path.join("templates",
@@ -40,12 +42,14 @@ class NetkitCompiler(PlatformCompiler):
                     }
 
 # allocate zebra information
-            if nidb_node.is_router:
+            nidb_node.add_stanza("zebra")
+            if nidb_node.is_router():
                 nidb_node.zebra.password = "1234"
             hostname = folder_name
             if hostname[0] in string.digits:
                 hostname = "r" + hostname
             nidb_node.hostname = hostname  # can't have . in quagga hostnames
+            nidb_node.add_stanza("ssh")
             nidb_node.ssh.use_key = True  # TODO: make this set based on presence of key
 
             # Note this could take external data
@@ -56,6 +60,7 @@ class NetkitCompiler(PlatformCompiler):
                 interface.id = self.index_to_int_id(numeric_id)
 
 # and allocate tap interface
+            nidb_node.add_stanza("tap")
             nidb_node.tap.id = self.index_to_int_id(int_ids.next())
 
             quagga_compiler.compile(nidb_node)
@@ -78,7 +83,7 @@ class NetkitCompiler(PlatformCompiler):
             or "172.16.0.0/16").iter_hosts() # added for backwards compatibility
         lab_topology.tap_host = address_block.next()
         lab_topology.tap_vm = address_block.next()  # for tunnel host
-        for node in sorted(self.nidb.nodes("is_l3device", host=self.host)):
+        for node in sorted(self.nidb.l3devices(host=self.host)):
             node.tap.ip = address_block.next()
 
     def lab_topology(self):
@@ -102,29 +107,30 @@ class NetkitCompiler(PlatformCompiler):
         subgraph = self.nidb.subgraph(host_nodes, self.host)
 
         lab_topology.machines = " ".join(alpha_sort(naming.network_hostname(phy_node)
-            for phy_node in subgraph.nodes("is_l3device")))
+            for phy_node in subgraph.l3devices()))
 
         lab_topology.config_items = []
-        for node in sorted(subgraph.nodes("is_l3device")):
+        for node in sorted(subgraph.l3devices()):
             for interface in node.physical_interfaces:
                 broadcast_domain = str(interface.ipv4_subnet).replace("/", ".")
                 #netkit lab.conf uses 1 instead of eth1
                 numeric_id = interface.numeric_id
-                lab_topology.config_items.append(
+                stanza = config_stanza(
                     device=naming.network_hostname(node),
                     key=numeric_id,
                     value=broadcast_domain,
                 )
+                lab_topology.config_items.append(stanza)
 
         lab_topology.tap_ips = []
         for node in subgraph:
             if node.tap:
-                lab_topology.tap_ips.append(
+                stanza = config_stanza(
                     device=naming.network_hostname(node),
                     id=node.tap.id.replace("eth", ""),  # strip ethx -> x
                     ip=node.tap.ip,
                 )
+                lab_topology.tap_ips.append(stanza)
 
-        lab_topology.tap_ips.sort("ip")
-        lab_topology.config_items.sort("device")
-
+        lab_topology.tap_ips = sorted(lab_topology.tap_ips, key = lambda x: x.ip)
+        lab_topology.config_items = sorted(lab_topology.config_items, key = lambda x: x.device)
\ No newline at end of file
