@@ -1,10 +1,12 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-import autonetkit.log as log
 import autonetkit.ank as ank_utils
-
+import autonetkit.config
+import autonetkit.log as log
 from autonetkit.ank_utils import call_log
 
+SETTINGS = autonetkit.config.settings
+
 
 @call_log
 def manual_ipv6_loopback_allocation(anm):
@@ -13,7 +15,7 @@ def manual_ipv6_loopback_allocation(anm):
     import netaddr
     g_ipv6 = anm['ipv6']
 
-    for l3_device in g_ipv6.nodes('is_l3device'):
+    for l3_device in g_ipv6.l3devices():
         l3_device.loopback = l3_device['input'].loopback_v6
 
     # also need to form aggregated IP blocks (used for e.g. routing prefix
@@ -21,12 +23,60 @@ def manual_ipv6_loopback_allocation(anm):
 
     loopback_blocks = {}
     for (asn, devices) in g_ipv6.groupby('asn').items():
-        routers = [d for d in devices if d.is_router]
+        routers = [d for d in devices if d.is_router()]
         loopbacks = [r.loopback for r in routers]
         loopback_blocks[asn] = netaddr.cidr_merge(loopbacks)
 
     g_ipv6.data.loopback_blocks = loopback_blocks
 
+@call_log
+def extract_ipv6_blocks(anm):
+
+    # TODO: set all these blocks globally in config file, rather than repeated in load, build_network, compile, etc
+
+    from autonetkit.ank import sn_preflen_to_network
+    from netaddr import IPNetwork
+    g_in = anm['input']
+
+    ipv6_defaults = SETTINGS["IP Addressing"]["v6"]
+
+    try:
+        infra_subnet = g_in.data.ipv6_infra_subnet
+        infra_prefix = g_in.data.ipv6_infra_prefix
+        infra_block = sn_preflen_to_network(infra_subnet, infra_prefix)
+    except Exception, e:
+        infra_block = IPNetwork('%s/%s' % (ipv6_defaults["infra_subnet"], ipv6_defaults["infra_prefix"]))
+        if infra_subnet is None or infra_prefix is None:
+            log.debug('Using default IPv6 infra_subnet %s'% infra_block)
+        else:
+            log.warning('Unable to obtain IPv6 infra_subnet from input graph: %s, using default %s'% (e, infra_block))
+
+    try:
+        loopback_subnet = g_in.data.ipv6_loopback_subnet
+        loopback_prefix = g_in.data.ipv6_loopback_prefix
+        loopback_block = sn_preflen_to_network(loopback_subnet,
+                loopback_prefix)
+    except Exception, e:
+        loopback_block = IPNetwork('%s/%s' % (ipv6_defaults["loopback_subnet"], ipv6_defaults["loopback_prefix"]))
+        if loopback_subnet is None or loopback_prefix is None:
+            log.debug('Using default IPv6 loopback_subnet %s'% loopback_block)
+        else:
+            log.warning('Unable to obtain IPv6 loopback_subnet from input graph: %s, using default %s'% (e, loopback_block))
+
+    try:
+        vrf_loopback_subnet = g_in.data.ipv6_vrf_loopback_subnet
+        vrf_loopback_prefix = g_in.data.ipv6_vrf_loopback_prefix
+        vrf_loopback_block = sn_preflen_to_network(vrf_loopback_subnet,
+                vrf_loopback_prefix)
+    except Exception, e:
+        vrf_loopback_block = IPNetwork('%s/%s' % (ipv6_defaults["vrf_loopback_subnet"], ipv6_defaults["vrf_loopback_prefix"]))
+        if vrf_loopback_subnet is None or vrf_loopback_prefix is None:
+            log.debug('Using default IPv6 vrf_loopback_subnet %s'% vrf_loopback_block)
+        else:
+            log.warning('Unable to obtain IPv6 vrf_loopback_subnet from input graph: %s, using default %s'% (e, vrf_loopback_block))
+
+    return (infra_block, loopback_block, vrf_loopback_block)
+
 @call_log
 def manual_ipv6_infrastructure_allocation(anm):
     """Applies manual IPv6 allocation"""
@@ -35,7 +85,7 @@ def manual_ipv6_infrastructure_allocation(anm):
     g_ipv6 = anm['ipv6']
     log.info('Using specified IPv6 infrastructure allocation')
 
-    for node in g_ipv6.nodes('is_l3device'):
+    for node in g_ipv6.l3devices():
         for interface in node.physical_interfaces:
             if not interface['input'].is_bound:
                 continue  # unbound interface
@@ -107,20 +157,19 @@ def build_ipv6(anm):
     g_ipv6.add_nodes_from(g_ip, retain=['label', 'asn', 'broadcast_domain'])  # retain if collision domain or not
     g_ipv6.add_edges_from(g_ip.edges())
 
-    global_pool = netaddr.IPNetwork('2001:db8::/32').subnet(48)
-    global_pool = netaddr.IPNetwork('::/32').subnet(64)
-    global_pool.next()  # network address
-    [global_pool.next() for i in range(9)]  # consume generator to start infra at "a", loopbacks at "b"
-    loopback_block = global_pool.next()
-    infra_block = global_pool.next()
-    secondary_loopback_block = global_pool.next()
+    #TODO: tidy up naming consitency of secondary_loopback_block and vrf_loopback_block
+    (infra_block, loopback_block, secondary_loopback_block) = \
+        extract_ipv6_blocks(anm)
 
     block_message = "IPv6 allocations: Infrastructure: %s, Loopback: %s" % (infra_block, loopback_block)
+    if any(i for n in g_ip.nodes() for i in
+     n.loopback_interfaces if not i.is_loopback_zero):
+        block_message += " Secondary Loopbacks: %s" % secondary_loopback_block
     log.info(block_message)
 
     # TODO: replace this with direct allocation to interfaces in ip alloc plugin
     allocated = sorted([n for n in g_ip if n['input'].loopback_v6])
-    if len(allocated) == len(g_ip.nodes("is_l3device")):
+    if len(allocated) == len(g_ip.l3devices()):
         # all allocated
         #TODO: need to infer subnetomanual_ipv6_loopback_allocation
         log.info("Using user-specified IPv6 loopback addresses")
@@ -133,7 +182,6 @@ def build_ipv6(anm):
 
         ipv6.allocate_loopbacks(g_ipv6, loopback_block)
 
-
     l3_devices = [d for d in g_in if d.device_type in ('router', 'server')]
 
     manual_alloc_devices = set()
@@ -168,7 +216,7 @@ def build_ipv6(anm):
     else:
         ipv6.allocate_infra(g_ipv6, infra_block)
         #TODO: see if this is still needed or if can allocate direct from the ipv6 allocation plugin
-        for node in g_ipv6.nodes('is_l3device'):
+        for node in g_ipv6.l3devices():
             for interface in node:
                 edges = list(interface.edges())
                 if len(edges):
@@ -176,10 +224,9 @@ def build_ipv6(anm):
                     interface.ip_address = edge.ip  # TODO: make this consistent
                     interface.subnet = edge.dst.subnet  # from collision domain
 
-
     ipv6.allocate_vrf_loopbacks(g_ipv6, secondary_loopback_block)
 
-    for node in g_ipv6.nodes('is_router'):
+    for node in g_ipv6.routers():
         #TODO: test this code
         node.loopback_zero.ip_address = node.loopback
         node.loopback_zero.subnet = netaddr.IPNetwork("%s/32" % node.loopback)
@@ -195,7 +242,7 @@ def manual_ipv4_infrastructure_allocation(anm):
     g_ipv4 = anm['ipv4']
     log.info('Using specified IPv4 infrastructure allocation')
 
-    for node in g_ipv4.nodes('is_l3device'):
+    for node in g_ipv4.l3devices():
         for interface in node.physical_interfaces:
             if not interface['input'].is_bound:
                 continue  # unbound interface
@@ -261,7 +308,7 @@ def manual_ipv4_loopback_allocation(anm):
     import netaddr
     g_ipv4 = anm['ipv4']
 
-    for l3_device in g_ipv4.nodes('is_l3device'):
+    for l3_device in g_ipv4.l3devices():
         l3_device.loopback = l3_device['input'].loopback_v4
 
     # also need to form aggregated IP blocks (used for e.g. routing prefix
@@ -269,7 +316,7 @@ def manual_ipv4_loopback_allocation(anm):
 
     loopback_blocks = {}
     for (asn, devices) in g_ipv4.groupby('asn').items():
-        routers = [d for d in devices if d.is_router]
+        routers = [d for d in devices if d.is_router()]
         loopbacks = [r.loopback for r in routers]
         loopback_blocks[asn] = netaddr.cidr_merge(loopbacks)
 
@@ -288,10 +335,10 @@ def build_ip(anm):
     g_ip.add_nodes_from(g_phy)
     g_ip.add_edges_from(g_phy.edges())
 
-    ank_utils.aggregate_nodes(g_ip, g_ip.nodes('is_switch'))
+    ank_utils.aggregate_nodes(g_ip, g_ip.switches())
 
     edges_to_split = [edge for edge in g_ip.edges()
-                      if edge.attr_both('is_l3device')]
+        if edge.src.is_l3device() and edge.dst.is_l3device()]
     for edge in edges_to_split:
         edge.split = True  # mark as split for use in building nidb
 
@@ -313,7 +360,7 @@ def build_ip(anm):
         node['graphics'].asn = asn
         node.asn = asn  # need to use asn in IP overlay for aggregating subnets
 
-    switch_nodes = g_ip.nodes('is_switch')  # regenerate due to aggregated
+    switch_nodes = g_ip.switches()  # regenerate due to aggregated
     g_ip.update(switch_nodes, broadcast_domain=True)
 
                  # switches are part of collision domain
@@ -334,9 +381,9 @@ def build_ip(anm):
     for node in g_ip.nodes('broadcast_domain'):
         graphics_node = g_graphics.node(node)
         #graphics_node.device_type = 'broadcast_domain'
-        if node.is_switch:
+        if node.is_switch():
             node['phy'].broadcast_domain = True
-        if not node.is_switch:
+        if not node.is_switch():
             # use node sorting, as accomodates for numeric/string names
             graphics_node.device_type = 'broadcast_domain'
             neighbors = sorted(neigh for neigh in node.neighbors())
@@ -355,15 +402,21 @@ def extract_ipv4_blocks(anm):
     from autonetkit.ank import sn_preflen_to_network
     from netaddr import IPNetwork
     g_in = anm['input']
+    ipv4_defaults = SETTINGS["IP Addressing"]["v4"]
+
+
+    #TODO: wrap these in a common function
 
     try:
         infra_subnet = g_in.data.ipv4_infra_subnet
         infra_prefix = g_in.data.ipv4_infra_prefix
         infra_block = sn_preflen_to_network(infra_subnet, infra_prefix)
     except Exception, e:
-        log.debug('Unable to obtain infra_subnet from input graph: %s'
-                  % e)
-        infra_block = IPNetwork('10.0.0.0/8')
+        infra_block = IPNetwork('%s/%s' % (ipv4_defaults["infra_subnet"], ipv4_defaults["infra_prefix"]))
+        if infra_subnet is None or infra_prefix is None:
+            log.debug('Using default IPv4 infra_subnet %s'% infra_block)
+        else:
+            log.warning('Unable to obtain IPv4 infra_subnet from input graph: %s, using default %s'% (e, infra_block))
 
     try:
         loopback_subnet = g_in.data.ipv4_loopback_subnet
@@ -371,9 +424,11 @@ def extract_ipv4_blocks(anm):
         loopback_block = sn_preflen_to_network(loopback_subnet,
                 loopback_prefix)
     except Exception, e:
-        log.debug('Unable to obtain loopback_subnet from input graph: %s'
-                   % e)
-        loopback_block = IPNetwork('10.0.0.0/8')
+        loopback_block = IPNetwork('%s/%s' % (ipv4_defaults["loopback_subnet"], ipv4_defaults["loopback_prefix"]))
+        if loopback_subnet is None or loopback_prefix is None:
+            log.debug('Using default IPv4 loopback_subnet %s'% loopback_block)
+        else:
+            log.warning('Unable to obtain IPv4 loopback_subnet from input graph: %s, using default %s'% (e, loopback_block))
 
     try:
         vrf_loopback_subnet = g_in.data.ipv4_vrf_loopback_subnet
@@ -381,9 +436,11 @@ def extract_ipv4_blocks(anm):
         vrf_loopback_block = sn_preflen_to_network(vrf_loopback_subnet,
                 vrf_loopback_prefix)
     except Exception, e:
-        log.debug('Unable to obtain vrf_loopback_subnet from input graph: %s'
-                   % e)
-        vrf_loopback_block = IPNetwork('172.16.0.0/24')
+        vrf_loopback_block = IPNetwork('%s/%s' % (ipv4_defaults["vrf_loopback_subnet"], ipv4_defaults["vrf_loopback_prefix"]))
+        if vrf_loopback_subnet is None or vrf_loopback_prefix is None:
+            log.debug('Using default IPv4 vrf_loopback_subnet %s'% vrf_loopback_block)
+        else:
+            log.warning('Unable to obtain IPv4 vrf_loopback_subnet from input graph: %s, using default %s'% (e, vrf_loopback_block))
 
     return (infra_block, loopback_block, vrf_loopback_block)
 
@@ -472,7 +529,7 @@ def build_ipv4(anm, infrastructure=True):
     # TODO: replace this with direct allocation to interfaces in ip alloc plugin
     #TODO: add option for nonzero interfaces on node - ie node.secondary_loopbacks
 
-    for node in g_ipv4.nodes('is_router'):
+    for node in g_ipv4.routers():
         node.loopback_zero.ip_address = node.loopback
         node.loopback_zero.subnet = netaddr.IPNetwork("%s/32" % node.loopback)
         for interface in node.loopback_interfaces:
