@@ -16,6 +16,7 @@ except ImportError:
 
 from collections import OrderedDict
 import logging
+from autonetkit.ank_utils import call_log
 
 
 class CustomAdapter(logging.LoggerAdapter):
@@ -25,18 +26,39 @@ class CustomAdapter(logging.LoggerAdapter):
 # based on http://docs.python.org/2.7/library/collections#collections.OrderedDict
 # and http://stackoverflow.com/q/455059
 class config_stanza(object):
-    def __init__(self, **kwargs):
+    def __init__(self, *args, **kwargs):
+        if len(args) == 1 and isinstance(args[0], config_stanza):
+            # Clone the data (shallow copy)
+            #TODO: check how this relates to calling dict() on a dict - same?
+            in_dict = args[0]._odict
+            object.__setattr__(self, '_odict', OrderedDict(in_dict))
+            return
+
+        if len(args) == 1 and isinstance(args[0], dict):
+            # Clone the data (shallow copy)
+            in_dict = args[0]
+            object.__setattr__(self, '_odict', OrderedDict(in_dict))
+            return
+
         object.__setattr__(self, '_odict', OrderedDict(kwargs))
 
     def __repr__(self):
         return str(self._odict.items())
 
+    def to_json(self):
+        retval = OrderedDict(self._odict) # clone to append to
+        retval['_config_stanza'] = True
+        return retval
+
     def add_stanza(self, name, **kwargs):
         """Adds a sub-stanza to this stanza"""
         stanza = config_stanza(**kwargs)
         self[name] = stanza
         return stanza
 
+    def __getitem__(self, key):
+        return self._odict[key]
+
     def __setitem__(self, key, value):
         if isinstance(value, dict):
             log.warning("Adding dictionary %s: did you mean to add a config_stanza?" % key)
@@ -50,6 +72,7 @@ class config_stanza(object):
         try:
             return self._odict[key]
         except KeyError:
+            #TODO: implement warning here
             #TODO: log a key miss, and if strict turned on, give warning
             return
 
@@ -57,6 +80,12 @@ class config_stanza(object):
         #TODO map this to proper dict inherit to support these methods, keys, etc
         return self._odict.items()
 
+    def __iter__(self):
+        return iter(self._odict.items())
+
+    def __len__(self):
+        return len(self._odict)
+
     # TODO: add __iter__, __keys etc
 
     #self.__dict__['_odict'][key] = value
@@ -65,6 +94,7 @@ class config_stanza(object):
 
 
 class interface_data_dict(collections.MutableMapping):
+    #TODO: replace with config stanza
     """A dictionary which allows access as dict.key as well as dict['key']
     Based on http://stackoverflow.com/questions/3387691
     only allows read only acess
@@ -110,110 +140,6 @@ class interface_data_dict(collections.MutableMapping):
     def dump(self):
         return self.store
 
-class overlay_data_dict(collections.MutableMapping):
-    """A dictionary which allows access as dict.key as well as dict['key']
-    Based on http://stackoverflow.com/questions/3387691
-    """
-
-    def __repr__(self):
-        return ", ".join(self.store.keys())
-
-    def __init__(self, parent, index, data):
-#Note this won't allow updates in place
-        self.parent = parent
-        self.index = index
-        self.store = data
-        #self.data = parent[index]
-        #self.update(dict(*args, **kwargs)) # use the free update to set keys
-#TODO: remove duplicate of self.store and parent
-
-    def __getitem__(self, key):
-        return self.store[self.__keytransform__(key)]
-
-    def __setitem__(self, key, value):
-        self.store[key] = value # store locally
-        self.parent._update_dict(self.index, key, value)
-
-    def __delitem__(self, key):
-        del self.store[self.__keytransform__(key)]
-
-    def __iter__(self):
-        return iter(self.store)
-
-    def __len__(self):
-        return len(self.store)
-
-    def __keytransform__(self, key):
-        return key
-
-    def __getattr__(self, key):
-        return self.store.get(key)
-
-#TODO: fix __setattr__ so doesn't cause recursion - and so doesn't silently not set values in compiler
-#same as for interfaces
-
-    def dump(self):
-        return self.store
-
-class overlay_data_list_of_dicts(object):
-    #NOTE: this is just a presentation of the data - so can't modify the original
-# but can do in place sort, append, etc
-    #TODO: make this inherit from list - so can remove .append() etc
-    def __init__(self, parent, key):
-        self.parent = parent
-        self.key = key
-        self.data = parent[key]
-
-    def __getstate__(self):
-        return (self.data)
-
-    def __getnewargs__(self):
-        return ()
-
-    def __setstate__(self, state):
-        self.data = state
-
-    def __len__(self):
-        return len(self.data)
-
-    def __repr__(self):
-        return str(self.data)
-
-    def __nonzero__(self):
-        """Allows for checking if data exists """
-        if len(self.data):
-            return True
-        else:
-            return False
-
-    def dump(self):
-        return self.data
-
-    def append(self, *args, **kwargs):
-        if args:
-            item = args[0]
-            self.data.append(item)
-        if kwargs:
-            self.data.append(kwargs)
-
-    def sort(self, key, reverse = False):
-        #TODO: allow multiple keys
-        self.data.sort(key = lambda x: x.get(key), reverse = reverse)
-
-    def __iter__(self):
-        #TODO: want to introduce some sorting here.... how?
-        #return iter(overlay_data_dict(self, item) for item in self.data)
-        for index, item in enumerate(self.data):
-            yield overlay_data_dict(self, index, item)
-
-    def __getitem__(self, index):
-        return overlay_data_dict(self, index, self.data[index])
-
-    def _update_dict(self, index, key, value):
-        """Used to feed changes from overlay_data_dict back"""
-        self.parent[self.key][index][key] = value
-
-
 class overlay_interface(object):
     def __init__(self, nidb, node_id, interface_id):
         object.__setattr__(self, 'nidb', nidb)
@@ -241,7 +167,7 @@ class overlay_interface(object):
 
     def __repr__(self):
         description = self.description or self.interface_id
-        return "(%s, %s)" % (self.node, description)
+        return "%s.%s" % (self.node, description)
 
     def __nonzero__(self):
         """Allows for checking if node exists
@@ -307,6 +233,7 @@ class overlay_interface(object):
             return
 
         if isinstance(data, dict):
+            #TODO: use config stanza instead?
             return interface_data_dict(data)
 
         return data
@@ -450,107 +377,6 @@ class overlay_node_accessor(object):
         """Access category"""
         return nidb_node_category(self.nidb, self.node_id, key)
 
-class nidb_node_subcategory(object):
-    def __init__(self, nidb, node_id, category_id, subcategory_id):
-#Set using this method to bypass __setattr__
-        object.__setattr__(self, 'nidb', nidb)
-        object.__setattr__(self, 'node_id', node_id)
-        object.__setattr__(self, 'category_id', category_id)
-        object.__setattr__(self, 'subcategory_id', subcategory_id)
-
-    @property
-    def _data(self):
-        return
-
-    def __repr__(self):
-        return self.nidb._graph.node[self.node_id][self.category_id][self.subcategory_id]
-
-class nidb_node_category(object):
-    #TODO: make this custom dict like above?
-    def __init__(self, nidb, node_id, category_id):
-#Set using this method to bypass __setattr__
-        object.__setattr__(self, 'nidb', nidb)
-        object.__setattr__(self, 'node_id', node_id)
-        object.__setattr__(self, 'category_id', category_id)
-
-    def __getstate__(self):
-        return (self.nidb, self.node_id, self.category_id)
-
-    def __getnewargs__(self):
-        return ()
-
-    def __setstate__(self, state):
-        """For pickling"""
-        self._overlays = state
-        (nidb, node_id, category_id) = state
-#TODO: call to self __init__ ???
-        object.__setattr__(self, 'nidb', nidb)
-        object.__setattr__(self, 'node_id', node_id)
-        object.__setattr__(self, 'category_id', category_id)
-
-    def __repr__(self):
-        return str(self._node_data.get(self.category_id))
-
-    def __nonzero__(self):
-        """Allows for accessing to set attributes
-        This simplifies templates
-        but also for easy check, eg if sw1.bgp can return False if category not set
-        but can later do r1.bgp.attr = value
-        """
-        if self.category_id in self._node_data:
-            if self._node_data[self.category_id]:
-                return True
-        return False
-
-    @property
-    def _category_data(self):
-        try:
-            return self._node_data[self.category_id]
-        except KeyError:
-            log.debug("No category_id %s in node %s" % (self.category_id, self.node_id))
-
-    def __getitem__(self, key):
-        """Used to access the data directly. calling node.key returns wrapped data for templates"""
-        return self._category_data[key]
-
-    @property
-    def _node_data(self):
-        return self.nidb._graph.node[self.node_id]
-
-    def __getattr__(self, key):
-        """Returns edge property"""
-#TODO: allow appending if non existent: so can do node.bgp.session.append(data)
-        try:
-            data = self._category_data.get(key)
-        except AttributeError:
-            return None # key doesn't exist
-        try:
-            [item.keys() for item in data]
-            #print "from nidb_node_category", self.nidb, self.node_id, self.category_id
-            return overlay_data_list_of_dicts(self._category_data, key)
-        except AttributeError:
-            pass # not a dict
-        except TypeError:
-            #Supress warning as could occur if this element is a primitive rather than a dict
-            #eg a boolean, which is valid
-            # TODO: revisit this
-            #log.debug("Access unset key %s in %s %s" % (key, self.node_id, self.category_id))
-            pass # also not a dict
-        return data
-
-    def dump(self):
-        return str(self._node_data)
-
-    def __setattr__(self, key, val):
-        """Sets edge property"""
-        try:
-            self._node_data[self.category_id][key] = val
-        except KeyError:
-            self._node_data[self.category_id] = {} # create dict for this data category
-            setattr(self, key, val)
-
-#TODO: this should also inherit from collections, so don't break __getnewargs__ etc
-
 @functools.total_ordering
 class nidb_node(object):
     """API to access overlay graph node in network"""
@@ -563,7 +389,8 @@ class nidb_node(object):
         #TODO: also pass the node object to the logger for building custom output lists
         # ie create a special handler that just outputs the specific node/link/interface errors
         logstring = "Node: %s" % str(self)
-        self.log = CustomAdapter(logger, {'item': logstring})
+        logger = CustomAdapter(logger, {'item': logstring})
+        object.__setattr__(self, 'log', logger)
 
     #TODO: make a json objct that returns keys that aren't logs, etc - filter out
 
@@ -587,6 +414,7 @@ class nidb_node(object):
                 self.log.debug("Stanza %s already exists" % name)
                 return value
             else:
+                #TODO: remove? - as shouldn't reach here now? GH-186
                 log.warning("Creating stanza: %s already set as %s for %s" % (name, type(value), self))
 
         stanza = config_stanza(**kwargs)
@@ -746,24 +574,25 @@ class nidb_node(object):
     def __nonzero__(self):
         return self.node_id in self.nidb._graph
 
-    @property
     def is_router(self):
         return self.device_type == "router"
 
-    @property
+    def is_device_type(self, device_type):
+        """Generic user-defined cross-overlay search for device_type for consistency with ANM"""
+        return self.device_type == device_type
+
     def is_switch(self):
         return self.device_type == "switch"
 
-    @property
     def is_server(self):
         return self.device_type == "server"
 
-    @property
     def is_l3device(self):
         """Layer 3 devices: router, server, cloud, host
         ie not switch
         """
-        return self.is_router or self.is_server
+        #TODO: need to check for cloud, host
+        return self.is_router() or self.is_server()
 
     def edges(self, *args, **kwargs):
         #TODO: want to add filter for *args and **kwargs here too
@@ -783,31 +612,12 @@ class nidb_node(object):
     def __getattr__(self, key):
         """Returns edge property"""
         data = self._node_data.get(key)
-        try:
-            [item.keys() for item in data]
-            #print "from nidb node", self.nidb, self.node_id, key
-            return overlay_data_list_of_dicts(self._node_data, key)
-        except TypeError:
-            pass # Not set yet
-        except AttributeError:
-            pass # not a dict
 
         #TODO: remove once deprecated nidb_node_category
         if isinstance(data, config_stanza):
             return data
 
-        try:
-            data.keys()
-            return nidb_node_category(self.nidb, self.node_id, key)
-        except TypeError:
-            pass # Not set yet
-        except AttributeError:
-            pass # not a dict
-
-        if data:
-            return data
-        else:
-            return nidb_node_category(self.nidb, self.node_id, key)
+        return data
 
     def __setattr__(self, key, val):
         """Sets edge property"""
@@ -864,17 +674,7 @@ class lab_topology(object):
     def __getattr__(self, key):
         """Returns topology property"""
         data = self._topology_data.get(key)
-        try:
-            [item.keys() for item in data]
-#TODO: replace this with an OrderedDict
-            #print "from lab_topology", self.nidb, self.topology_id, key
-            return overlay_data_list_of_dicts(self._topology_data, key)
-        except AttributeError:
-            pass # not a dict
-        except TypeError:
-            pass # also not a dict
         return data
-        return self._topology_data.get(key)
 
     def __setattr__(self, key, val):
         """Sets topology property"""
@@ -971,6 +771,7 @@ class NIDB_base(object):
     def copy_graphics(self, G_graphics):
         """Transfers graphics data from anm to nidb"""
         for node in self:
+            node.add_stanza("graphics")
             graphics_node = G_graphics.node(node)
             node.graphics.x = graphics_node.x
             node.graphics.y = graphics_node.y
@@ -1051,8 +852,26 @@ class NIDB_base(object):
 
     def routers(self, *args, **kwargs):
         """Shortcut for nodes(), sets device_type to be router"""
-        kwargs['device_type'] = 'router'
-        return self.nodes(*args, **kwargs)
+
+        result = self.nodes(*args, **kwargs)
+        return [r for r in result if r.is_router()]
+
+    def switches(self, *args, **kwargs):
+        """Shortcut for nodes(), sets device_type to be switch"""
+
+        result = self.nodes(*args, **kwargs)
+        return [r for r in result if r.is_switch()]
+
+    def servers(self, *args, **kwargs):
+            """Shortcut for nodes(), sets device_type to be server"""
+
+            result = self.nodes(*args, **kwargs)
+            return [r for r in result if r.is_server()]
+
+    def l3devices(self, *args, **kwargs):
+        """Shortcut for nodes(), sets device_type to be server"""
+        result = self.nodes(*args, **kwargs)
+        return [r for r in result if r.is_l3device()]
 
     def filter(self, nbunch = None, *args, **kwargs):
         #TODO: also allow nbunch to be passed in to subfilter on...?
