@@ -13,6 +13,7 @@ import autonetkit.ank_messaging
 import autonetkit.log as log
 import netaddr
 import networkx as nx
+from autonetkit.exception import AutoNetkitException
 
 # TODO: allow slack in allocations: both for ASN (group level), and for collision domains to allow new nodes to be easily added
 
@@ -198,6 +199,8 @@ class IpTree(object):
 
         unallocated_nodes = sorted(unallocated_nodes, key=key_func)
         groupings = itertools.groupby(unallocated_nodes, key=key_func)
+        prefixes_by_attr = {}
+
         for (attr_value, items) in groupings:
 
 # make subtree for each attr
@@ -230,7 +233,7 @@ class IpTree(object):
                     subgraph.node[root_node]['group_attr'] = attr_value
                     continue  # finished for loopbacks, continue only for collision domains
 
-            if all(item.is_l3device for item in items):
+            if all(item.is_l3device() for item in items):
 
                 # Note: only l3 devices are added for loopbacks: cds allocate to edges not devices (for now) - will be fixed when move to proper interface model
 
@@ -256,7 +259,7 @@ class IpTree(object):
                 if item.broadcast_domain:
                     subgraph.add_node(self.next_node_id, prefixlen=32
                             - subnet_size(item.degree()), host=item)
-                if item.is_l3device:
+                if item.is_l3device():
                     subgraph.add_node(self.next_node_id, prefixlen=32,
                             host=item)
 
@@ -315,6 +318,7 @@ class IpTree(object):
 
             subgraph.node[root_node]['prefixlen'] = 16
             subgraph.node[root_node]['group_attr'] = attr_value
+            prefixes_by_attr[attr_value] = subgraph.node[root_node]['prefixlen']
 
         global_graph = nx.DiGraph()
         subgraphs = sorted(subgraphs, key=lambda x: \
@@ -363,11 +367,12 @@ class IpTree(object):
             global_ip_block = \
                 self.root_ip_block.subnet(global_prefix_len).next()
         except StopIteration:
-            log.error('Unable to subnet IP block: trying to create subnets of size %s from %s'
-                       % (global_prefix_len,
-                      self.root_ip_block.prefixlen))
-            raise SystemExit  # TODO: throw ANK specific exception here
-            return
+            #message = ("Unable to allocate IPv4 subnets. ")
+            formatted_prefixes = ", ".join("AS%s: /%s" % (k,v) for k,v in sorted(prefixes_by_attr.items()))
+            message = ("Cannot create requested number of /%s subnets from root block %s. Please specify a larger root IP block. (Requested subnet allocations are: %s)"
+                       % (global_prefix_len, self.root_ip_block, formatted_prefixes))
+            log.error(message)
+            raise AutoNetkitException(message)  # TODO: throw ANK specific exception here
         self.graph = global_graph
 
 # add children of collision domains
@@ -543,9 +548,10 @@ class IpTree(object):
 
 # assigns allocated addresses back to hosts
         # don't look at host nodes now - use loopback_groups
-
+        #TODO: make check for interface and loopback zero now
         host_tree_nodes = [n for n in self if n.is_host()
-                           and n.host.is_l3device]
+                            and isinstance(n.host, autonetkit.anm.OverlayNode)
+                           and n.host.is_l3device()]
 
         # for host_tree_node in host_tree_nodes:
             # print host_tree_node, host_tree_node.subnet
@@ -619,7 +625,7 @@ def allocate_loopbacks(g_ip, address_block=None):
         address_block = netaddr.IPNetwork('192.168.0.0/22')
     log.info('Allocating v4 Primary Host loopback IPs')
     ip_tree = IpTree(address_block)
-    ip_tree.add_nodes(g_ip.nodes('is_l3device'))
+    ip_tree.add_nodes(g_ip.l3devices())
     ip_tree.build()
 
     # loopback_tree = ip_tree.json()
