@@ -50,7 +50,7 @@ def allocate_loopbacks(g_ip, address_block=None):
     for (asn, devices) in g_ip.groupby('asn').items():
         loopback_hosts = loopback_blocks[asn].iter_hosts()
         loopback_hosts.next()  # drop .0 as a host address (valid but can be confusing)
-        l3hosts = set(d for d in devices if d.is_l3device)
+        l3hosts = set(d for d in devices if d.is_l3device())
         for host in sorted(l3hosts, key=lambda x: x.label):
             host.loopback = loopback_hosts.next()
 
@@ -72,7 +72,7 @@ def allocate_infra(g_ip, address_block=None):
     for asn in sorted(unique_asns):
         infra_blocks[asn] = infra_pool.next()
 
-    for (asn, devices) in g_ip.groupby('asn').items():
+    for (asn, devices) in sorted(g_ip.groupby('asn').items()):
         subnets = infra_blocks[asn].subnet(96)
         subnets.next()  # network address
         ptp_subnet = subnets.next().subnet(126)
@@ -117,8 +117,8 @@ def allocate_vrf_loopbacks(g_ip, address_block=None):
             secondary_loopback_network.next()
 
     for (asn, devices) in g_ip.groupby('asn').items():
-        l3hosts = set(d for d in devices if d.is_l3device)
-        routers = [n for n in l3hosts if n.is_router]  # filter
+        l3hosts = set(d for d in devices if d.is_l3device())
+        routers = [n for n in l3hosts if n.is_router()]  # filter
         secondary_loopbacks = [i for n in routers for i in
                                n.loopback_interfaces
                                if not i.is_loopback_zero]
@@ -128,6 +128,7 @@ def allocate_vrf_loopbacks(g_ip, address_block=None):
         secondary_loopback_hosts.next()  # drop .0 as a host address (valid but can be confusing)
         for interface in sorted(secondary_loopbacks):
             interface.loopback = secondary_loopback_hosts.next()
+            interface.subnet = netaddr.IPNetwork("%s/128" % interface.loopback)
 
 def allocate_ips(G_ip, infra_block = None, loopback_block = None, secondary_loopback_block = None):
     log.info('Allocating Host loopback IPs')
